package masterproef.rulerunner;

import java.util.HashMap;
import java.util.Map;

import org.drools.KnowledgeBase;
import org.drools.KnowledgeBaseFactory;
import org.drools.builder.KnowledgeBuilder;
import org.drools.builder.KnowledgeBuilderError;
import org.drools.builder.KnowledgeBuilderErrors;
import org.drools.builder.KnowledgeBuilderFactory;
import org.drools.builder.ResourceType;
import org.drools.io.ResourceFactory;
import org.drools.logger.KnowledgeRuntimeLogger;
import org.drools.logger.KnowledgeRuntimeLoggerFactory;
import org.drools.runtime.StatefulKnowledgeSession;

/**
 * This is a sample file to launch a process.
 */
public class FeverRunner{
    
    private static final long serialVersionUID = 4L;
    
    private KnowledgeBase kbase;
    private StatefulKnowledgeSession ksession;
    private KnowledgeRuntimeLogger logger;
    private BMIClass bmiClass;

    public static void main(String[] args) {
        new FeverRunner();
    }
    
    public FeverRunner() {
        try {
            // load up the knowledge base
            kbase = createKnowledgeBase();
            createWorkingMemory();
            logger = KnowledgeRuntimeLoggerFactory.newFileLogger(ksession, "test");
            bmiClass = new BMIClass(20);
            Map<String, Object> parameters = new HashMap<String, Object>();
            parameters.put("bmiClass", bmiClass);
            ksession.insert(bmiClass);
            //ksession.setGlobal("bmiClass", bmiClass);
            ksession.startProcess("bmi.testflow", parameters);         
            logger.close();
        } catch (Throwable t) {
            t.printStackTrace();
        }
    }

    private void createWorkingMemory() {
        try {
            ksession = kbase.newStatefulKnowledgeSession(); 
        } catch (Throwable t) {
            t.printStackTrace();
        }
    }
  
    private KnowledgeBase createKnowledgeBase() throws Exception {
        KnowledgeBuilder kbuilder = KnowledgeBuilderFactory.newKnowledgeBuilder();
        kbuilder.add(ResourceFactory.newClassPathResource(
                "BMIFlow.rf", FeverRunner.class), ResourceType.DRF );
        kbuilder.add(ResourceFactory.newClassPathResource(
                "masterproef/rules/checkTemperature.drl", FeverRunner.class), ResourceType.DRL );
        
        KnowledgeBuilderErrors errors = kbuilder.getErrors();
        if (errors.size() > 0) {
            for (KnowledgeBuilderError error: errors) {
                System.err.println(error);
            }
            throw new IllegalArgumentException("Could not parse knowledge.");
        }
        kbase = KnowledgeBaseFactory.newKnowledgeBase();
        kbase.addKnowledgePackages(kbuilder.getKnowledgePackages());
        return kbase;
    }      
}